summaryrefslogtreecommitdiffstats
path: root/gst/level
diff options
context:
space:
mode:
authorThomas Vander Stichele <thomas@apestaart.org>2005-10-19 20:48:24 +0000
committerThomas Vander Stichele <thomas@apestaart.org>2005-10-19 20:48:24 +0000
commit587a7add24025601ce2cf9e6b6cdff5942540ccf (patch)
treea61d91c7278a4a9a63d6246e8f235b77992cb4ef /gst/level
parent3ab46f21f0422bd01b2a56e21246a36207be865d (diff)
use ELEMENT messages instead
Original commit message from CVS: use ELEMENT messages instead
Diffstat (limited to 'gst/level')
-rw-r--r--gst/level/gstlevel.c4
-rw-r--r--gst/level/level-example.c2
2 files changed, 3 insertions, 3 deletions
diff --git a/gst/level/level-example.c b/gst/level/level-example.c
index ed647de2..3333a8c8 100644
--- a/gst/level/level-example.c
+++ b/gst/level/level-example.c
@@ -7,7 +7,7 @@ gboolean
message_handler (GstBus * bus, GstMessage * message, gpointer data)
{
- if (message->type == GST_MESSAGE_APPLICATION) {
+ if (message->type == GST_MESSAGE_ELEMENT) {
const GstStructure *s = gst_message_get_structure (message);
const gchar *name = gst_structure_get_name (s);
diff --git a/gst/level/gstlevel.c b/gst/level/gstlevel.c
index 88d56812..9a15caf4 100644
--- a/gst/level/gstlevel.c
+++ b/gst/level/gstlevel.c
@@ -26,7 +26,7 @@
* <para>
* Level analyses incoming audio buffers and, if the
* <link linkend="GstLevel--message">message property</link> is #TRUE,
* generates an application message named
* <classname>&quot;level&quot;</classname>:
* after each interval of time given by the
* <link linkend="GstLevel--interval">interval property</link>.
@@ -366,7 +366,7 @@ gst_level_message_new (GstLevel * l, GstClockTime endtime)
gst_structure_set_value (s, "peak", &v);
gst_structure_set_value (s, "decay", &v);
- return gst_message_new_application (GST_OBJECT (l), s);
+ return gst_message_new_element (GST_OBJECT (l), s);
}
static void
@@ -26,7 +26,7 @@
* Level analyses incoming audio buffers and, if the
* <link linkend="GstLevel--message">message property</link> is #TRUE,
- * generates an application message named
+ * generates an element message named
* <classname>&quot;level&quot;</classname>:
* after each interval of time given by the